#
# spec file for package flex
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           flex
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  gcc-c++
BuildRequires:  help2man
BuildRequires:  makeinfo
Url:            http://flex.sourceforge.net/
Requires:       m4
PreReq:         %install_info_prereq
# bug437293
%ifarch ppc64
Obsoletes:      flex-64bit
%endif
#
Version:        2.5.37
Release:        13.91
Summary:        Fast Lexical Analyzer Generator
License:        BSD-3-Clause
Group:          Development/Languages/C and C++
Source:         http://prdownloads.sourceforge.net/flex/flex-%{version}.tar.bz2
Source1:        lex-wrapper.sh
Source2:        README.SUSE
Source3:        baselibs.conf
Patch1:         flex-2.5.34-fPIC.patch
# PATCH-FIX-OPENSUSE Remove tex dependency, info is enough for us, we don't need pdf - coolo@suse.de
Patch2:         flex-2.5.37-notex.patch
# PATCH-FIX-UPSTREAM fix tests for new bison
Patch3:         http://www.linuxfromscratch.org/patches/lfs/7.2/flex-2.5.37-bison-2.6.1-1.patch
Patch4:         config-guess-sub-update.patch
Patch5:         0001-Changed-type-of-yy_n_chars-to-int-gh-53-sf-160.patch
Patch6:         0002-Changed-another-buffer-size-to-int-resolves-gh-61.patch
Patch7:         0003-Removed-some-type-conversion-warnings.patch
Patch8:         0004-Fixed-incorrect-integer-type.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
FLEX is a tool for generating scanners: programs that recognize lexical
patterns in text.

%prep
%setup -q
%patch1
%patch2 -p1
%patch3 -p1
%patch4
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1

%build
autoreconf -fi
%configure --docdir=%{_docdir}/%{name}
make %{?_smp_mflags}

%check
%if !0%{?qemu_user_space_build:1}
make check
%endif

%install
make install DESTDIR=$RPM_BUILD_ROOT
install %{S:1}  $RPM_BUILD_ROOT/%{_bindir}/lex
ln -s flex.1.gz $RPM_BUILD_ROOT/%{_mandir}/man1/lex.1.gz
cp %{S:2} $RPM_BUILD_ROOT/%{_docdir}/%{name}
%find_lang %{name}

%files -f %{name}.lang
%defattr(-,root,root)
/usr/bin/flex
/usr/bin/flex++
/usr/bin/lex
/usr/include/FlexLexer.h
%{_libdir}/libfl.a
%{_mandir}/man1/flex.1.gz
%{_mandir}/man1/lex.1.gz
%{_infodir}/flex*
%{_docdir}/%name

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%changelog
* Thu Aug  4 2016 mmarek@suse.cz
- Fix buffer overflow in the generated scanner (bsc#990856,
  CVE-2016-6354).
  0001-Changed-type-of-yy_n_chars-to-int-gh-53-sf-160.patch
  0002-Changed-another-buffer-size-to-int-resolves-gh-61.patch
  0003-Removed-some-type-conversion-warnings.patch
  0004-Fixed-incorrect-integer-type.patch
* Mon Feb 18 2013 schwab@suse.de
- config-guess-sub-update.patch:
  Update config.guess/sub for aarch64
* Tue Oct 16 2012 coolo@suse.com
- update to 2.5.37
  * * Import flex into git. See
    git://flex.git.sourceforge.net/gitroot/flex/flex.
  * * Fix make install target to not fail when the flex++ program is
    already installed
  * * New translations from the translation project: de, fi, pl, vi
  * * various portability fixes that quiet compiler warnings on 64-bit
    hosts
  * * various manual fixes, including correcting the name of a %%option and
    updating some simple examples to use ANSI C syntax
  * * various bug fixes that prevent certain error conditions from
    persisting when they should not persist
  * * improvements to the test suite so it behaves better when linking
    compiled files
  * * new translations from the translation project: ca, da, es, fi, fr,
    ga, ko, pt_br, ro, ru, sv, tr, zh_cn
  * * the flex distribution is now built with automake 1.10.1 and automake
    2.61
- add patch flex-2.5.37-notex.patch to compile without texlive
- remove patches no longer required:
  flex-2.5.33-yylineno.patch
  flex-2.5.34-doc-fix.diff
  flex-2.5.34-g++44.diff
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Mon Oct  3 2011 dmueller@suse.de
- fix compile failure outside ARM
* Fri Sep 30 2011 max@suse.com
- Skip the test suite when building in qemu userspace emulation
  to fix and speedup build on ARM.
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
* Sun Dec 13 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Sat Jun 13 2009 coolo@novell.com
- fix link line
* Mon Jan 12 2009 rguenther@suse.de
- Add patch to include <cstdio> in the C++ header section.  Fixes
  the C++ parts of the testsuite with GCC 4.4.
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Fri Feb 29 2008 mmarek@suse.cz
- updated to 2.5.35
  * includes previous fixes
  * translation updates
* Tue Feb 19 2008 mmarek@suse.cz
- updated with fixes from flex CVS to fix following bugs in 2.5.34:
  [#1849809], #1849805, #1628314, #1849812 (details at
  http://sourceforge.net/tracker/?group_id=97492&atid=618177 )
* Tue Jan 15 2008 mmarek@suse.cz
- updated to 2.5.34
  * introduce yylex_init_extra; see the manual for details
  * introduce %%option extra-type="your_type *"
  * The flex program now parses multiple short concatenated options
    Thanks to Petr Machata of Red Hat on this issue.
  * Expose YY_BUF_SIZE in the header file.
  * pattern language expanded; see the manual for details on the
    below highlights
  * pattern options added to specify patterns as case-insensitive
    or case-sensitive
  * pattern options to specify whether the "." character should
    match the newline character
  * pattern options added to allow ignoring of whitespace in
    patterns
  * POSIX character classes may be negated in patterns
  * patterns may now use set difference, union operators
  * the manual now contains an appendix listing various common
    patterns which may be useful when writing scanners
  * c++ scanners can now use yywrap
  * flex man page and flex manual in pdf now distributed in the
    flex distribution
  * bugfixes and translation updates
* Mon Mar 26 2007 rguenther@suse.de
- Add bison BuildRequires.
* Wed May 17 2006 mmarek@suse.cz
- update to 2.5.33
  * bugfix release
  * obsoleted patches:
  - YY_DECL.patch
  - array-yymore.patch
  - double-free.patch
  - keep-macros.patch
  - overflow.patch
  * kept fPIC.patch, yylineno.patch and doc-fix.diff
* Tue May 16 2006 agruen@suse.de
- A minor fix in the documentation.
* Thu Mar  9 2006 mmarek@suse.cz
- keep YY_* macros in the generated C file (backport from 2.5.33)
  [#141964#c6] (keep-yytext_ptr.patch -> keep-macros.patch)
* Wed Mar  8 2006 mmarek@suse.cz
- removed unneeded part of last fix (C++ scanners weren't affected)
  [#151087] (overflow.patch)
* Fri Feb 17 2006 mmarek@suse.cz
- fix buffer overflow in some generated scanners
  [#151087] (overflow.patch)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 20 2005 mmj@suse.de
- don't package /usr/share/info/dir
* Thu Dec 15 2005 mmarek@suse.cz
- added README.SUSE, packaged some %%%%doc files
* Mon Dec  5 2005 mmarek@suse.cz
- don't declare int yylineno in non-reentrant scanners without
  %%option yylineno -- programs declaring their own yylineno should
  build now
  (yylineno.patch)
* Mon Nov 28 2005 mmarek@suse.cz
- test-noansi-r didn't pass on 64bit, fix from CVS
  (YY_DECL.patch)
* Tue Nov 22 2005 mmarek@suse.cz
- update to version 2.5.31 once again...
* Mon Nov  7 2005 mmarek@suse.cz
- compile libfl.a with -fPIC
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Mon Sep 15 2003 tcrhak@suse.cz
- Use <iostream> and std namespace in flex.skl [bug #30427]
* Fri Aug  1 2003 coolo@suse.de
- don't strip explicitly
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Fri Feb  7 2003 ro@suse.de
- added install_info macros
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Sat Jul 27 2002 kukuk@suse.de
- remove yacc from neededforbuild, bison is used
* Wed Jun 26 2002 tcrhak@suse.cz
- update to 2.5.4a (slight change in license only)
- bzipped sources
* Tue Jan  8 2002 schwab@suse.de
- Use <iostream> and std namespace in FlexLexer.h.
* Tue Jul 31 2001 nadvornik@suse.cz
- installed info pages [bug #9566]
- added buildroot
* Wed Apr 11 2001 nadvornik@suse.cz
- declaration of isatty replaced with include<unistd.h>
* Mon Apr  2 2001 schwab@suse.de
- Don't try to forward declare class istream, just include <iostream.h>.
* Tue Nov 21 2000 kukuk@suse.de
- Use macros to support multilib plattforms
* Tue Apr  4 2000 bk@suse.de
- flex needs yacc for building on s390
* Fri Feb 25 2000 schwab@suse.de
- Specfile cleanup, get rid of Makefile.Linux
- /usr/man -> /usr/share/man
- Add group tag
- Fix lex script
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Feb  6 1997 rj@suse.de
- new version 2.5.4
